@@ -2,7 +2,7 @@ from fastapi import APIRouter, Depends, Query
 from sqlalchemy.orm import Session
 from typing import Optional, List
 from .db import get_session
-from .views import get_categories, get_group_by_category
+from .views import get_categories, get_group_by_category, refresh_view
 from .models import GroupedCategory
 
 collection_route = APIRouter(
@@ -20,9 +20,12 @@ async def get_index_category(
     form: Optional[int] = Query(default=None),
     name: Optional[str] = Query(default=None),
     category: Optional[str] = Query(default=None),
-    data: Optional[int] = Query(default=None),
+    data: Optional[str] = Query(default=None),
     session: Session = Depends(get_session),
 ):
+    if data:
+        data = [int(d) for d in data.split(",")]
+        data = data[0] if len(data) == 1 else data
     res = get_categories(
         form=form, name=name, category=category, data=data, session=session
     )
@@ -44,3 +47,16 @@ async def get_grouped_categories(
         session=session, form_id=form_id, category_name=category_name
     )
     return res
+
+
+@collection_route.get(
+    "/refresh",
+    summary="refresh materialized view",
+    name="collection:refresh_materialized_view",
+    tags=["Data"],
+)
+def refresh_materialized_view(
+    session: Session = Depends(get_session),
+):
+    refresh_view(session=session)
+    return "OK"
